Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(24)

Unified Diff: chrome/browser/autofill/autofill_popup_view.h

Issue 9432029: GTK Keyboard Support for New Autofill (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Fixing Shift Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/autofill/autofill_popup_view.h
diff --git a/chrome/browser/autofill/autofill_popup_view.h b/chrome/browser/autofill/autofill_popup_view.h
index 1ca890871d350d846787c2da28aa1f1c505318ef..1495474e87fafd9894b62bfaca56377fa86409ed 100644
--- a/chrome/browser/autofill/autofill_popup_view.h
+++ b/chrome/browser/autofill/autofill_popup_view.h
@@ -75,6 +75,21 @@ class AutofillPopupView : public content::NotificationObserver {
// Change which line is currently selected by the user.
void SetSelectedLine(int selected_line);
+ // Increase the selected line by 1, properly handling wrapping.
+ void SelectNextLine();
+
+ // Decrease the selected line by 1, properly handling wrapping.
+ void SelectPreviousLine();
+
+ // The user has choosen the selected line.
+ bool AcceptSelectedLine();
+
+ // The user has removed a suggestion.
+ bool RemoveSelectedLine();
+
+ // Used to indicate that no line is currently selected by the user.
+ const int kNoSelection = -1;
+
private:
// content::NotificationObserver method override.
virtual void Observe(int type,
@@ -100,7 +115,7 @@ class AutofillPopupView : public content::NotificationObserver {
int separator_index_;
// The line that is currently selected by the user.
// -1 indicates that no line is currently selected.
int selected_line_;
};
@@ -100,7 +115,7 @@ class AutofillPopupView : public content::NotificationObserver {
int separator_index_;
// The line that is currently selected by the user.
- // -1 indicates that no line is currently selected.
+ // |kNoSelection| indicates that no line is currently selected.
int selected_line_;
};

Powered by Google App Engine
This is Rietveld 408576698